Class: Square::Devices::Codes::Client
- Inherits:
-
Object
- Object
- Square::Devices::Codes::Client
- Defined in:
- lib/square/devices/codes/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Square::Types::CreateDeviceCodeResponse
Creates a DeviceCode that can be used to login to a Square Terminal device to enter the connected terminal mode.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetDeviceCodeResponse
Retrieves DeviceCode with the associated ID.
- #initialize(client:) ⇒ Square::Devices::Codes::Client constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListDeviceCodesResponse
Lists all DeviceCodes associated with the merchant.
Constructor Details
#initialize(client:) ⇒ Square::Devices::Codes::Client
8 9 10 |
# File 'lib/square/devices/codes/client.rb', line 8 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Square::Types::CreateDeviceCodeResponse
Creates a DeviceCode that can be used to login to a Square Terminal device to enter the connected terminal mode.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/square/devices/codes/client.rb', line 47 def create(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/devices/codes", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CreateDeviceCodeResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetDeviceCodeResponse
Retrieves DeviceCode with the associated ID.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/square/devices/codes/client.rb', line 71 def get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/devices/codes/#{params[:id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::GetDeviceCodeResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListDeviceCodesResponse
Lists all DeviceCodes associated with the merchant.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/square/devices/codes/client.rb', line 15 def list(request_options: {}, **params) _query_param_names = [ %w[cursor location_id product_type status], %i[cursor location_id product_type status] ].flatten _query = params.slice(*_query_param_names) params.except(*_query_param_names) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/devices/codes", query: _query ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::ListDeviceCodesResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |