Class: Square::TeamMembers::Client
- Inherits:
-
Object
- Object
- Square::TeamMembers::Client
- Defined in:
- lib/square/team_members/client.rb
Instance Method Summary collapse
-
#batch_create(request_options: {}, **params) ⇒ Square::Types::BatchCreateTeamMembersResponse
Creates multiple
TeamMemberobjects. -
#batch_update(request_options: {}, **params) ⇒ Square::Types::BatchUpdateTeamMembersResponse
Updates multiple
TeamMemberobjects. -
#create(request_options: {}, **params) ⇒ Square::Types::CreateTeamMemberResponse
Creates a single
TeamMemberobject. -
#get(request_options: {}, **params) ⇒ Square::Types::GetTeamMemberResponse
Retrieves a
TeamMemberobject for the givenTeamMember.id. - #initialize(client:) ⇒ void constructor
-
#search(request_options: {}, **params) ⇒ Square::Types::SearchTeamMembersResponse
Returns a paginated list of
TeamMemberobjects for a business. -
#update(request_options: {}, **params) ⇒ Square::Types::UpdateTeamMemberResponse
Updates a single
TeamMemberobject. - #wage_setting ⇒ Square::WageSetting::Client
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/square/team_members/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#batch_create(request_options: {}, **params) ⇒ Square::Types::BatchCreateTeamMembersResponse
Creates multiple TeamMember objects. The created TeamMember objects are returned on successful creates.
This process is non-transactional and processes as much of the request as possible. If one of the creates in
the request cannot be successfully processed, the request is not marked as failed, but the body of the response
contains explicit error information for the failed create.
Learn about Troubleshooting the Team API.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/square/team_members/client.rb', line 70 def batch_create(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/team-members/bulk-create", body: Square::TeamMembers::Types::BatchCreateTeamMembersRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::BatchCreateTeamMembersResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#batch_update(request_options: {}, **params) ⇒ Square::Types::BatchUpdateTeamMembersResponse
Updates multiple TeamMember objects. The updated TeamMember objects are returned on successful updates.
This process is non-transactional and processes as much of the request as possible. If one of the updates in
the request cannot be successfully processed, the request is not marked as failed, but the body of the response
contains explicit error information for the failed update.
Learn about Troubleshooting the Team
API.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/square/team_members/client.rb', line 109 def batch_update(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/team-members/bulk-update", body: Square::TeamMembers::Types::BatchUpdateTeamMembersRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::BatchUpdateTeamMembersResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#create(request_options: {}, **params) ⇒ Square::Types::CreateTeamMemberResponse
Creates a single TeamMember object. The TeamMember object is returned on successful creates.
You must provide the following values in your request to this endpoint:
given_namefamily_name
Learn about Troubleshooting the Team API.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/square/team_members/client.rb', line 30 def create(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/team-members", body: Square::Types::CreateTeamMemberRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CreateTeamMemberResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetTeamMemberResponse
Retrieves a TeamMember object for the given TeamMember.id.
Learn about Troubleshooting the Team
API.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/square/team_members/client.rb', line 182 def get(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/team-members/#{params[:team_member_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetTeamMemberResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#search(request_options: {}, **params) ⇒ Square::Types::SearchTeamMembersResponse
Returns a paginated list of TeamMember objects for a business.
The list can be filtered by location IDs, ACTIVE or INACTIVE status, or whether
the team member is the Square account owner.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/square/team_members/client.rb', line 145 def search(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/team-members/search", body: Square::TeamMembers::Types::SearchTeamMembersRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::SearchTeamMembersResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Square::Types::UpdateTeamMemberResponse
Updates a single TeamMember object. The TeamMember object is returned on successful updates.
Learn about Troubleshooting the Team
API.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/square/team_members/client.rb', line 218 def update(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[team_member_id] body_params = params.except(*path_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "v2/team-members/#{params[:team_member_id]}", body: Square::Types::UpdateTeamMemberRequest.new(body_params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::UpdateTeamMemberResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#wage_setting ⇒ Square::WageSetting::Client
245 246 247 |
# File 'lib/square/team_members/client.rb', line 245 def wage_setting @wage_setting ||= Square::TeamMembers::WageSetting::Client.new(client: @client) end |