Class: Square::Types::Booking

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/booking.rb

Overview

Represents a booking as a time-bound service contract for a seller’s staff member to provide a specified service at a given location to a requesting customer in one or more appointment segments.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model