Class: Square::Types::Card

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/card.rb

Overview

Represents the payment details of a card to be used for payments. These details are determined by the payment token generated by Web Payments SDK.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model