Class: Square::Types::CashDrawerShift
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CashDrawerShift
- Defined in:
- lib/square/types/cash_drawer_shift.rb
Overview
This model gives the details of a cash drawer shift. The cash_payment_money, cash_refund_money, cash_paid_in_money, and cash_paid_out_money fields are all computed by summing their respective event types.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model