Class: Square::Types::CreatePaymentResponse
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CreatePaymentResponse
- Defined in:
- lib/square/types/create_payment_response.rb
Overview
Defines the response returned by [CreatePayment](api-endpoint:Payments-CreatePayment).
If there are errors processing the request, the ‘payment` field might not be present, or it might be present with a status of `FAILED`.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model