Class: Square::Types::CustomField
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomField
- Defined in:
- lib/square/types/custom_field.rb
Overview
Describes a custom form field to add to the checkout page to collect more information from buyers during checkout. For more information, see [Specify checkout options](developer.squareup.com/docs/checkout-api/optional-checkout-configurations#specify-checkout-options-1).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model