Class: Square::Types::CustomerCreatedEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/customer_created_event.rb

Overview

Published when a [customer](entity:Customer) is created. Subscribe to this event to track customer profiles affected by a merge operation. For more information, see [Use Customer Webhooks](developer.squareup.com/docs/customers-api/use-the-api/customer-webhooks).

The ‘customer` object in the event notification does not include the `segment_ids` field.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model