Class: Square::Types::CustomerCustomAttributeDefinitionDeletedPublicEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/customer_custom_attribute_definition_deleted_public_event.rb

Overview

Published when a customer [custom attribute definition](entity:CustomAttributeDefinition) that is visible to all applications is deleted. A notification is sent when any application deletes a custom attribute definition whose ‘visibility` is `VISIBILITY_READ_ONLY` or `VISIBILITY_READ_WRITE_VALUES`.

This event is replaced by [customer.custom_attribute_definition.visible.deleted](webhook:customer.custom_attribute_definition.visible.deleted), which applies to custom attribute definitions that are visible to the subscribing application.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model