Class: Square::Types::CustomerCustomAttributeDefinitionVisibleDeletedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomerCustomAttributeDefinitionVisibleDeletedEvent
- Defined in:
- lib/square/types/customer_custom_attribute_definition_visible_deleted_event.rb
Overview
Published when a customer custom attribute definition
that is visible to the subscribing application is deleted. A custom attribute definition can only be deleted
by the application that created it. A notification is sent when your application deletes a custom attribute
definition or when another application deletes a custom attribute definition whose visibility is
VISIBILITY_READ_ONLY or VISIBILITY_READ_WRITE_VALUES.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model