Class: Square::Types::CustomerCustomAttributeDeletedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomerCustomAttributeDeletedEvent
- Defined in:
- lib/square/types/customer_custom_attribute_deleted_event.rb
Overview
Published when a customer custom attribute owned by the
subscribing application is deleted. Custom attributes are owned by the application that created the
corresponding custom attribute definition. Custom attributes whose
visibility is VISIBILITY_READ_WRITE_VALUES can be deleted by any application.
This event is replaced by customer.custom_attribute.owned.deleted.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model