Class: Square::Types::CustomerCustomAttributeOwnedUpdatedEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/customer_custom_attribute_owned_updated_event.rb

Overview

Published when a customer custom attribute owned by the subscribing application is created or updated. Custom attributes are owned by the application that created the corresponding custom attribute definition. Custom attributes whose visibility is VISIBILITY_READ_WRITE_VALUES can be created or updated by any application.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model