Class: Square::Types::CustomerCustomAttributeUpdatedPublicEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomerCustomAttributeUpdatedPublicEvent
- Defined in:
- lib/square/types/customer_custom_attribute_updated_public_event.rb
Overview
Published when a customer [custom attribute](entity:CustomAttribute) that is visible to all applications is created or updated. A notification is sent when any application creates or updates a custom attribute whose ‘visibility` is `VISIBILITY_READ_ONLY` or `VISIBILITY_READ_WRITE_VALUES`.
This event is replaced by [customer.custom_attribute.visible.updated](webhook:customer.custom_attribute.visible.updated), which applies to custom attributes that are visible to the subscribing application.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model