Class: Square::Types::InventoryCount

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/inventory_count.rb

Overview

Represents Square-estimated quantity of items in a particular state at a particular seller location based on the known history of physical counts and inventory adjustments. The absence of an inventory count indicates that the catalog object hasn't interacted with the given inventory state at the given location.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model