Class: Square::Types::LocationCustomAttributeDefinitionVisibleUpdatedEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/location_custom_attribute_definition_visible_updated_event.rb

Overview

Published when a location [custom attribute definition](entity:CustomAttributeDefinition) that is visible to the subscribing application is updated. A custom attribute definition can only be updated by the application that created it. A notification is sent when your application updates a custom attribute definition or when another application updates a custom attribute definition whose ‘visibility` is `VISIBILITY_READ_ONLY` or `VISIBILITY_READ_WRITE_VALUES`.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model