Class: Square::Types::LocationCustomAttributeVisibleDeletedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::LocationCustomAttributeVisibleDeletedEvent
- Defined in:
- lib/square/types/location_custom_attribute_visible_deleted_event.rb
Overview
Published when a location custom attribute that is visible to the subscribing application is deleted. A notification is sent when:
- Your application deletes a custom attribute owned by your application, regardless of the
visibilitysetting. - Any application deletes a custom attribute whose
visibilityisVISIBILITY_READ_ONLYorVISIBILITY_READ_WRITE_VALUES.
Custom attributes set to VISIBILITY_READ_WRITE_VALUES can be deleted by any application, but those set to
VISIBILITY_READ_ONLY or VISIBILITY_HIDDEN can only be deleted by the owner. Custom attributes are owned
by the application that created the corresponding custom attribute definition.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model