Class: Square::Types::LoyaltyAccountExpiringPointDeadline

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/loyalty_account_expiring_point_deadline.rb

Overview

Represents a set of points for a loyalty account that are scheduled to expire on a specific date.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model