Class: Square::Types::LoyaltyPromotion

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/loyalty_promotion.rb

Overview

Represents a promotion for a [loyalty program](entity:LoyaltyProgram). Loyalty promotions enable buyers to earn extra points on top of those earned from the base program.

A loyalty program can have a maximum of 10 loyalty promotions with an ‘ACTIVE` or `SCHEDULED` status.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model