Class: Square::Types::LoyaltyPromotionIncentive
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::LoyaltyPromotionIncentive
- Defined in:
- lib/square/types/loyalty_promotion_incentive.rb
Overview
Represents how points for a [loyalty promotion](entity:LoyaltyPromotion) are calculated, either by multiplying the points earned from the base program or by adding a specified number of points to the points earned from the base program.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model