Class: Square::Types::MerchantCustomAttributeDefinitionVisibleDeletedEvent

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/merchant_custom_attribute_definition_visible_deleted_event.rb

Overview

Published when a merchant [custom attribute definition](entity:CustomAttributeDefinition) that is visible to the subscribing application is deleted. A notification is sent when your application deletes a custom attribute definition or another application deletes a custom attribute definition whose ‘visibility` is `VISIBILITY_READ_ONLY` or `VISIBILITY_READ_WRITE_VALUES`.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model