Class: Square::Types::MerchantCustomAttributeVisibleDeletedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::MerchantCustomAttributeVisibleDeletedEvent
- Defined in:
- lib/square/types/merchant_custom_attribute_visible_deleted_event.rb
Overview
Published when a merchant [custom attribute](entity:CustomAttribute) with the ‘visibility` field set to `VISIBILITY_READ_ONLY` or `VISIBILITY_READ_WRITE_VALUES` is deleted. An application that subscribes to this event is notified when a merchant custom attribute is deleted by any application for which the subscribing application has read access to the merchant custom attribute.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model