Class: Square::Types::PayoutEntry
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::PayoutEntry
- Defined in:
- lib/square/types/payout_entry.rb
Overview
One or more PayoutEntries that make up a Payout. Each one has a date, amount, and type of activity. The total amount of the payout will equal the sum of the payout entries for a batch payout
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model