Class: Square::Types::ScheduledShiftDetails

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/scheduled_shift_details.rb

Overview

Represents shift details for draft and published versions of a [scheduled shift](entity:ScheduledShift), such as job ID, team member assignment, and start and end times.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model