Class: Square::Types::ShiftWorkday

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/shift_workday.rb

Overview

A ‘Shift` search query filter parameter that sets a range of days that a `Shift` must start or end in before passing the filter condition.

Deprecated at Square API version 2025-05-21. See the [migration notes](developer.squareup.com/docs/labor-api/what-it-does#migration-notes).

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model