Class: Square::Types::Snippet
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Snippet
- Defined in:
- lib/square/types/snippet.rb
Overview
Represents the snippet that is added to a Square Online site. The snippet code is injected into the ‘head` element of all pages on the site, except for checkout pages.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model