Class: Square::Types::Timecard
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Timecard
- Defined in:
- lib/square/types/timecard.rb
Overview
A record of the hourly rate, start time, and end time of a single timecard (shift) for a team member. This might include a record of the start and end times of breaks taken during the shift.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model