Class: SquareLegacy::OAuthApi
- Defined in:
- lib/square_legacy/api/o_auth_api.rb
Overview
OAuthApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#obtain_token(body:) ⇒ ApiResponse
Returns an OAuth access token and a refresh token unless the
short_livedparameter is set totrue, in which case the endpoint returns only an access token. -
#retrieve_token_status ⇒ ApiResponse
Returns information about an [OAuth access token](https://developer.squareup.com/docs/build-basics/access-tokens#get- an-oauth-access-token) or an application’s [personal access token](https://developer.squareup.com/docs/build-basics/access-tokens#get- a-personal-access-token).
-
#revoke_token(body:, authorization:) ⇒ ApiResponse
Revokes an access token generated with the OAuth flow.
Methods inherited from BaseApi
#initialize, #new_api_call_builder, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from SquareLegacy::BaseApi
Instance Method Details
#obtain_token(body:) ⇒ ApiResponse
Returns an OAuth access token and a refresh token unless the
short_lived parameter is set to true, in which case the endpoint
returns only an access token.
The grant_type parameter specifies the type of OAuth request. If
grant_type is authorization_code, you must include the authorization
code you received when a seller granted you authorization. If grant_type
is refresh_token, you must provide a valid refresh token. If you're
using
an old version of the Square APIs (prior to March 13, 2019), grant_type
can be migration_token and you must provide a valid migration token.
You can use the scopes parameter to limit the set of permissions granted
to the access token and refresh token. You can use the short_lived
parameter
to create an access token that expires in 24 hours.
Note: OAuth tokens should be encrypted and stored on a secure server.
Application clients should never interact directly with OAuth tokens.
the fields to POST for the request. See the corresponding object
definition for field details.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/square_legacy/api/o_auth_api.rb', line 59 def obtain_token(body:) new_api_call_builder .request(new_request_builder(HttpMethodEnum::POST, '/oauth2/token', 'default') .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end)) .response(new_response_handler .deserializer(APIHelper.method(:json_deserialize)) .is_api_response(true) .convertor(ApiResponse.method(:create))) .execute end |
#retrieve_token_status ⇒ ApiResponse
Returns information about an [OAuth access
token](https://developer.squareup.com/docs/build-basics/access-tokens#get-
an-oauth-access-token) or an application’s [personal access
token](https://developer.squareup.com/docs/build-basics/access-tokens#get-
a-personal-access-token).
Add the access token to the Authorization header of the request.
Important: The Authorization header you provide to this endpoint
must have the following format:
Authorization: Bearer ACCESS_TOKEN
where ACCESS_TOKEN is a
valid production authorization
credential.
If the access token is expired or not a valid access token, the endpoint
returns an UNAUTHORIZED error.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/square_legacy/api/o_auth_api.rb', line 93 def retrieve_token_status new_api_call_builder .request(new_request_builder(HttpMethodEnum::POST, '/oauth2/token/status', 'default') .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('global'))) .response(new_response_handler .deserializer(APIHelper.method(:json_deserialize)) .is_api_response(true) .convertor(ApiResponse.method(:create))) .execute end |
#revoke_token(body:, authorization:) ⇒ ApiResponse
Revokes an access token generated with the OAuth flow.
If an account has more than one OAuth access token for your application,
this
endpoint revokes all of them, regardless of which token you specify.
Important: The Authorization header for this endpoint must have the
following format:
Authorization: Client APPLICATION_SECRET
Replace APPLICATION_SECRET with the application secret on the OAuth
page for your application in the Developer Dashboard.
the fields to POST for the request. See the corresponding object
definition for field details.
APPLICATION_SECRET
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/square_legacy/api/o_auth_api.rb', line 21 def revoke_token(body:, authorization:) new_api_call_builder .request(new_request_builder(HttpMethodEnum::POST, '/oauth2/revoke', 'default') .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .header_param(new_parameter(, key: 'Authorization')) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end)) .response(new_response_handler .deserializer(APIHelper.method(:json_deserialize)) .is_api_response(true) .convertor(ApiResponse.method(:create))) .execute end |