Class: Square::BookingsApi
- Defined in:
- lib/square/api/bookings_api.rb
Overview
BookingsApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#cancel_booking(booking_id:, body:) ⇒ CancelBookingResponse Hash
Cancels an existing booking.
-
#create_booking(body:) ⇒ CreateBookingResponse Hash
Creates a booking.
-
#initialize(config, http_call_back: nil) ⇒ BookingsApi
constructor
A new instance of BookingsApi.
-
#list_team_member_booking_profiles(bookable_only: false, limit: nil, cursor: nil, location_id: nil) ⇒ ListTeamMemberBookingProfilesResponse Hash
Lists booking profiles for team members.
-
#retrieve_booking(booking_id:) ⇒ RetrieveBookingResponse Hash
Retrieves a booking.
-
#retrieve_business_booking_profile ⇒ RetrieveBusinessBookingProfileResponse Hash
Retrieves a seller's booking profile.
-
#retrieve_team_member_booking_profile(team_member_id:) ⇒ RetrieveTeamMemberBookingProfileResponse Hash
Retrieves a team member's booking profile.
-
#search_availability(body:) ⇒ SearchAvailabilityResponse Hash
Searches for availabilities for booking.
-
#update_booking(booking_id:, body:) ⇒ UpdateBookingResponse Hash
Updates a booking.
Methods inherited from BaseApi
#execute_request, #validate_parameters
Constructor Details
#initialize(config, http_call_back: nil) ⇒ BookingsApi
Returns a new instance of BookingsApi.
4 5 6 |
# File 'lib/square/api/bookings_api.rb', line 4 def initialize(config, http_call_back: nil) super(config, http_call_back: http_call_back) end |
Instance Method Details
#cancel_booking(booking_id:, body:) ⇒ CancelBookingResponse Hash
Cancels an existing booking. [Booking]($m/Booking) object representing the to-be-cancelled booking. containing the fields to POST for the request. See the corresponding object definition for field details.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/square/api/bookings_api.rb', line 272 def cancel_booking(booking_id:, body:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/{booking_id}/cancel' _query_builder = APIHelper.append_url_with_template_parameters( _query_builder, 'booking_id' => { 'value' => booking_id, 'encode' => true } ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json', 'content-type' => 'application/json; charset=utf-8' } # Prepare and execute HttpRequest. _request = config.http_client.post( _query_url, headers: _headers, parameters: body.to_json ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#create_booking(body:) ⇒ CreateBookingResponse Hash
Creates a booking. containing the fields to POST for the request. See the corresponding object definition for field details.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/square/api/bookings_api.rb', line 13 def create_booking(body:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings' _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json', 'content-type' => 'application/json; charset=utf-8' } # Prepare and execute HttpRequest. _request = config.http_client.post( _query_url, headers: _headers, parameters: body.to_json ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#list_team_member_booking_profiles(bookable_only: false, limit: nil, cursor: nil, location_id: nil) ⇒ ListTeamMemberBookingProfilesResponse Hash
Lists booking profiles for team members. include only bookable team members in the returned result (`true`) or not (`false`). to return. through the results. include only team members enabled at the given location in the returned result.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/square/api/bookings_api.rb', line 117 def list_team_member_booking_profiles(bookable_only: false, limit: nil, cursor: nil, location_id: nil) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/team-member-booking-profiles' _query_builder = APIHelper.append_url_with_query_parameters( _query_builder, 'bookable_only' => bookable_only, 'limit' => limit, 'cursor' => cursor, 'location_id' => location_id ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#retrieve_booking(booking_id:) ⇒ RetrieveBookingResponse Hash
Retrieves a booking. [Booking]($m/Booking) object representing the to-be-retrieved booking.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/square/api/bookings_api.rb', line 193 def retrieve_booking(booking_id:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/{booking_id}' _query_builder = APIHelper.append_url_with_template_parameters( _query_builder, 'booking_id' => { 'value' => booking_id, 'encode' => true } ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#retrieve_business_booking_profile ⇒ RetrieveBusinessBookingProfileResponse Hash
Retrieves a seller's booking profile.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/square/api/bookings_api.rb', line 78 def retrieve_business_booking_profile # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/business-booking-profile' _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#retrieve_team_member_booking_profile(team_member_id:) ⇒ RetrieveTeamMemberBookingProfileResponse Hash
Retrieves a team member's booking profile. member to retrieve.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/square/api/bookings_api.rb', line 158 def retrieve_team_member_booking_profile(team_member_id:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/team-member-booking-profiles/{team_member_id}' _query_builder = APIHelper.append_url_with_template_parameters( _query_builder, 'team_member_id' => { 'value' => team_member_id, 'encode' => true } ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#search_availability(body:) ⇒ SearchAvailabilityResponse Hash
Searches for availabilities for booking. containing the fields to POST for the request. See the corresponding object definition for field details.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/square/api/bookings_api.rb', line 47 def search_availability(body:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/availability/search' _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json', 'content-type' => 'application/json; charset=utf-8' } # Prepare and execute HttpRequest. _request = config.http_client.post( _query_url, headers: _headers, parameters: body.to_json ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#update_booking(booking_id:, body:) ⇒ UpdateBookingResponse Hash
Updates a booking. [Booking]($m/Booking) object representing the to-be-updated booking. containing the fields to POST for the request. See the corresponding object definition for field details.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/square/api/bookings_api.rb', line 231 def update_booking(booking_id:, body:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/bookings/{booking_id}' _query_builder = APIHelper.append_url_with_template_parameters( _query_builder, 'booking_id' => { 'value' => booking_id, 'encode' => true } ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json', 'content-type' => 'application/json; charset=utf-8' } # Prepare and execute HttpRequest. _request = config.http_client.put( _query_url, headers: _headers, parameters: body.to_json ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |