Class: Square::Cards::Client
- Inherits:
-
Object
- Object
- Square::Cards::Client
- Defined in:
- lib/square/cards/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Square::Types::CreateCardResponse
Adds a card on file to an existing merchant.
-
#disable(request_options: {}, **params) ⇒ Square::Types::DisableCardResponse
Disables the card, preventing any further updates or charges.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetCardResponse
Retrieves details for a specific Card.
- #initialize(client:) ⇒ Square::Cards::Client constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListCardsResponse
Retrieves a list of cards owned by the account making the request.
Constructor Details
#initialize(client:) ⇒ Square::Cards::Client
7 8 9 |
# File 'lib/square/cards/client.rb', line 7 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Square::Types::CreateCardResponse
Adds a card on file to an existing merchant.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/square/cards/client.rb', line 46 def create(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/cards", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CreateCardResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#disable(request_options: {}, **params) ⇒ Square::Types::DisableCardResponse
Disables the card, preventing any further updates or charges. Disabling an already disabled card is allowed but has no effect.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/square/cards/client.rb', line 94 def disable(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/cards/#{params[:card_id]}/disable" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::DisableCardResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetCardResponse
Retrieves details for a specific Card.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/square/cards/client.rb', line 70 def get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/cards/#{params[:card_id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::GetCardResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListCardsResponse
Retrieves a list of cards owned by the account making the request. A max of 25 cards will be returned.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/square/cards/client.rb', line 15 def list(request_options: {}, **params) _query_param_names = [ %w[cursor customer_id include_disabled reference_id sort_order], %i[cursor customer_id include_disabled reference_id sort_order] ].flatten _query = params.slice(*_query_param_names) params.except(*_query_param_names) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/cards", query: _query ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::ListCardsResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |