Class: Square::Checkout::PaymentLinks::Client
- Inherits:
-
Object
- Object
- Square::Checkout::PaymentLinks::Client
- Defined in:
- lib/square/checkout/payment_links/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Square::Types::CreatePaymentLinkResponse
Creates a Square-hosted checkout page.
-
#delete(request_options: {}, **params) ⇒ Square::Types::DeletePaymentLinkResponse
Deletes a payment link.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetPaymentLinkResponse
Retrieves a payment link.
- #initialize(client:) ⇒ Square::Checkout::PaymentLinks::Client constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListPaymentLinksResponse
Lists all payment links.
-
#update(request_options: {}, **params) ⇒ Square::Types::UpdatePaymentLinkResponse
Updates a payment link.
Constructor Details
#initialize(client:) ⇒ Square::Checkout::PaymentLinks::Client
8 9 10 |
# File 'lib/square/checkout/payment_links/client.rb', line 8 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Square::Types::CreatePaymentLinkResponse
Creates a Square-hosted checkout page. Applications can share the resulting payment link with their buyer to pay for goods and services.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/square/checkout/payment_links/client.rb', line 46 def create(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/online-checkout/payment-links", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CreatePaymentLinkResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ Square::Types::DeletePaymentLinkResponse
Deletes a payment link.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/square/checkout/payment_links/client.rb', line 121 def delete(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "DELETE", path: "v2/online-checkout/payment-links/#{params[:id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::DeletePaymentLinkResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetPaymentLinkResponse
Retrieves a payment link.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/square/checkout/payment_links/client.rb', line 70 def get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/online-checkout/payment-links/#{params[:id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::GetPaymentLinkResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListPaymentLinksResponse
Lists all payment links.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/square/checkout/payment_links/client.rb', line 15 def list(request_options: {}, **params) _query_param_names = [ %w[cursor limit], %i[cursor limit] ].flatten _query = params.slice(*_query_param_names) params.except(*_query_param_names) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/online-checkout/payment-links", query: _query ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::ListPaymentLinksResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Square::Types::UpdatePaymentLinkResponse
Updates a payment link. You can update the ‘payment_link` fields such as `description`, `checkout_options`, and `pre_populated_data`. You cannot update other fields such as the `order_id`, `version`, `URL`, or `timestamp` field.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/square/checkout/payment_links/client.rb', line 95 def update(request_options: {}, **params) _path_param_names = ["id"] _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "PUT", path: "v2/online-checkout/payment-links/#{params[:id]}", body: params.except(*_path_param_names) ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::UpdatePaymentLinkResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |