Class: Square::CustomerSegmentsApi
- Defined in:
- lib/square/api/customer_segments_api.rb
Overview
CustomerSegmentsApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#initialize(config, http_call_back: nil) ⇒ CustomerSegmentsApi
constructor
A new instance of CustomerSegmentsApi.
-
#list_customer_segments(cursor: nil, limit: nil) ⇒ ListCustomerSegmentsResponse Hash
Retrieves the list of customer segments of a business.
-
#retrieve_customer_segment(segment_id:) ⇒ RetrieveCustomerSegmentResponse Hash
Retrieves a specific customer segment as identified by the `segment_id` value.
Methods inherited from BaseApi
#execute_request, #get_user_agent, #validate_parameters
Constructor Details
#initialize(config, http_call_back: nil) ⇒ CustomerSegmentsApi
Returns a new instance of CustomerSegmentsApi.
4 5 6 |
# File 'lib/square/api/customer_segments_api.rb', line 4 def initialize(config, http_call_back: nil) super(config, http_call_back: http_call_back) end |
Instance Method Details
#list_customer_segments(cursor: nil, limit: nil) ⇒ ListCustomerSegmentsResponse Hash
Retrieves the list of customer segments of a business. previous calls to `ListCustomerSegments`. This cursor is used to retrieve the next set of query results. For more information, see [Pagination](developer.squareup.com/docs/build-basics/common-api-p atterns/pagination). to return in a single page. This limit is advisory. The response might contain more or fewer results. If the specified limit is less than 1 or greater than 50, Square returns a `400 VALUE_TOO_LOW` or `400 VALUE_TOO_HIGH` error. The default value is 50. For more information, see [Pagination](developer.squareup.com/docs/build-basics/common-api-p atterns/pagination).
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/square/api/customer_segments_api.rb', line 22 def list_customer_segments(cursor: nil, limit: nil) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/customers/segments' _query_builder = APIHelper.append_url_with_query_parameters( _query_builder, 'cursor' => cursor, 'limit' => limit ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |
#retrieve_customer_segment(segment_id:) ⇒ RetrieveCustomerSegmentResponse Hash
Retrieves a specific customer segment as identified by the `segment_id` value. customer segment.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/square/api/customer_segments_api.rb', line 60 def retrieve_customer_segment(segment_id:) # Prepare query url. _query_builder = config.get_base_uri _query_builder << '/v2/customers/segments/{segment_id}' _query_builder = APIHelper.append_url_with_template_parameters( _query_builder, 'segment_id' => { 'value' => segment_id, 'encode' => true } ) _query_url = APIHelper.clean_url _query_builder # Prepare headers. _headers = { 'accept' => 'application/json' } # Prepare and execute HttpRequest. _request = config.http_client.get( _query_url, headers: _headers ) OAuth2.apply(config, _request) _response = execute_request(_request) # Return appropriate response type. decoded = APIHelper.json_deserialize(_response.raw_body) _errors = APIHelper.map_response(decoded, ['errors']) ApiResponse.new( _response, data: decoded, errors: _errors ) end |