Class: Square::Customers::Groups::Client
- Inherits:
-
Object
- Object
- Square::Customers::Groups::Client
- Defined in:
- lib/square/customers/groups/client.rb
Instance Method Summary collapse
-
#add(request_options: {}, **params) ⇒ Square::Types::AddGroupToCustomerResponse
Adds a group membership to a customer.
-
#create(request_options: {}, **params) ⇒ Square::Types::CreateCustomerGroupResponse
Creates a new customer group for a business.
-
#delete(request_options: {}, **params) ⇒ Square::Types::DeleteCustomerGroupResponse
Deletes a customer group as identified by the ‘group_id` value.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetCustomerGroupResponse
Retrieves a specific customer group as identified by the ‘group_id` value.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListCustomerGroupsResponse
Retrieves the list of customer groups of a business.
-
#remove(request_options: {}, **params) ⇒ Square::Types::RemoveGroupFromCustomerResponse
Removes a group membership from a customer.
-
#update(request_options: {}, **params) ⇒ Square::Types::UpdateCustomerGroupResponse
Updates a customer group as identified by the ‘group_id` value.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/square/customers/groups/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#add(request_options: {}, **params) ⇒ Square::Types::AddGroupToCustomerResponse
Adds a group membership to a customer.
The customer is identified by the ‘customer_id` value and the customer group is identified by the `group_id` value.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/square/customers/groups/client.rb', line 222 def add(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "v2/customers/#{params[:customer_id]}/groups/#{params[:group_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::AddGroupToCustomerResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#create(request_options: {}, **params) ⇒ Square::Types::CreateCustomerGroupResponse
Creates a new customer group for a business.
The request must include the ‘name` value of the group.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/square/customers/groups/client.rb', line 76 def create(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/customers/groups", body: Square::Customers::Groups::Types::CreateCustomerGroupRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CreateCustomerGroupResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ Square::Types::DeleteCustomerGroupResponse
Deletes a customer group as identified by the ‘group_id` value.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/square/customers/groups/client.rb', line 184 def delete(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "v2/customers/groups/#{params[:group_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::DeleteCustomerGroupResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetCustomerGroupResponse
Retrieves a specific customer group as identified by the ‘group_id` value.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/square/customers/groups/client.rb', line 111 def get(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/customers/groups/#{params[:group_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetCustomerGroupResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListCustomerGroupsResponse
Retrieves the list of customer groups of a business.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/square/customers/groups/client.rb', line 27 def list(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[cursor limit] query_params = {} query_params["cursor"] = params[:cursor] if params.key?(:cursor) query_params["limit"] = params[:limit] if params.key?(:limit) params.except(*query_param_names) Square::Internal::CursorItemIterator.new( cursor_field: :cursor, item_field: :groups, initial_cursor: query_params[:cursor] ) do |next_cursor| query_params[:cursor] = next_cursor request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/customers/groups", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::ListCustomerGroupsResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#remove(request_options: {}, **params) ⇒ Square::Types::RemoveGroupFromCustomerResponse
Removes a group membership from a customer.
The customer is identified by the ‘customer_id` value and the customer group is identified by the `group_id` value.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/square/customers/groups/client.rb', line 260 def remove(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "v2/customers/#{params[:customer_id]}/groups/#{params[:group_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::RemoveGroupFromCustomerResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Square::Types::UpdateCustomerGroupResponse
Updates a customer group as identified by the ‘group_id` value.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/square/customers/groups/client.rb', line 145 def update(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request_data = Square::Customers::Groups::Types::UpdateCustomerGroupRequest.new(params).to_h non_body_param_names = ["group_id"] body = request_data.except(*non_body_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "v2/customers/groups/#{params[:group_id]}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::UpdateCustomerGroupResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |