Class: Square::Customers::Segments::Client
- Inherits:
-
Object
- Object
- Square::Customers::Segments::Client
- Defined in:
- lib/square/customers/segments/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Square::Types::GetCustomerSegmentResponse
Retrieves a specific customer segment as identified by the ‘segment_id` value.
- #initialize(client:) ⇒ Square::Customers::Segments::Client constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListCustomerSegmentsResponse
Retrieves the list of customer segments of a business.
Constructor Details
#initialize(client:) ⇒ Square::Customers::Segments::Client
8 9 10 |
# File 'lib/square/customers/segments/client.rb', line 8 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Square::Types::GetCustomerSegmentResponse
Retrieves a specific customer segment as identified by the ‘segment_id` value.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/square/customers/segments/client.rb', line 46 def get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/customers/segments/#{params[:segment_id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::GetCustomerSegmentResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListCustomerSegmentsResponse
Retrieves the list of customer segments of a business.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/square/customers/segments/client.rb', line 15 def list(request_options: {}, **params) _query_param_names = [ %w[cursor limit], %i[cursor limit] ].flatten _query = params.slice(*_query_param_names) params.except(*_query_param_names) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/customers/segments", query: _query ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::ListCustomerSegmentsResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |