Class: Square::GiftCards::Client
- Inherits:
-
Object
- Object
- Square::GiftCards::Client
- Defined in:
- lib/square/gift_cards/client.rb
Instance Method Summary collapse
- #activities ⇒ Square::Activities::Client
-
#create(request_options: {}, **params) ⇒ Square::Types::CreateGiftCardResponse
Creates a digital gift card or registers a physical (plastic) gift card.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetGiftCardResponse
Retrieves a gift card using the gift card ID.
-
#get_from_gan(request_options: {}, **params) ⇒ Square::Types::GetGiftCardFromGanResponse
Retrieves a gift card using the gift card account number (GAN).
-
#get_from_nonce(request_options: {}, **params) ⇒ Square::Types::GetGiftCardFromNonceResponse
Retrieves a gift card using a secure payment token that represents the gift card.
- #initialize(client:) ⇒ void constructor
-
#link_customer(request_options: {}, **params) ⇒ Square::Types::LinkCustomerToGiftCardResponse
Links a customer to a gift card, which is also referred to as adding a card on file.
-
#list(request_options: {}, **params) ⇒ Square::Types::ListGiftCardsResponse
Lists all gift cards.
-
#unlink_customer(request_options: {}, **params) ⇒ Square::Types::UnlinkCustomerFromGiftCardResponse
Unlinks a customer from a gift card, which is also referred to as removing a card on file.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/square/gift_cards/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#activities ⇒ Square::Activities::Client
289 290 291 |
# File 'lib/square/gift_cards/client.rb', line 289 def activities @activities ||= Square::GiftCards::Activities::Client.new(client: @client) end |
#create(request_options: {}, **params) ⇒ Square::Types::CreateGiftCardResponse
Creates a digital gift card or registers a physical (plastic) gift card. The resulting gift card has a ‘PENDING` state. To activate a gift card so that it can be redeemed for purchases, call [CreateGiftCardActivity](api-endpoint:GiftCardActivities-CreateGiftCardActivity) and create an `ACTIVATE` activity with the initial balance. Alternatively, you can use [RefundPayment](api-endpoint:Refunds-RefundPayment) to refund a payment to the new gift card.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/square/gift_cards/client.rb', line 85 def create(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/gift-cards", body: Square::GiftCards::Types::CreateGiftCardRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CreateGiftCardResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetGiftCardResponse
Retrieves a gift card using the gift card ID.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/square/gift_cards/client.rb', line 266 def get(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/gift-cards/#{params[:id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetGiftCardResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_from_gan(request_options: {}, **params) ⇒ Square::Types::GetGiftCardFromGanResponse
Retrieves a gift card using the gift card account number (GAN).
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/square/gift_cards/client.rb', line 119 def get_from_gan(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/gift-cards/from-gan", body: Square::GiftCards::Types::GetGiftCardFromGanRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetGiftCardFromGanResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_from_nonce(request_options: {}, **params) ⇒ Square::Types::GetGiftCardFromNonceResponse
Retrieves a gift card using a secure payment token that represents the gift card.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/square/gift_cards/client.rb', line 153 def get_from_nonce(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/gift-cards/from-nonce", body: Square::GiftCards::Types::GetGiftCardFromNonceRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetGiftCardFromNonceResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#link_customer(request_options: {}, **params) ⇒ Square::Types::LinkCustomerToGiftCardResponse
Links a customer to a gift card, which is also referred to as adding a card on file.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/square/gift_cards/client.rb', line 188 def link_customer(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request_data = Square::GiftCards::Types::LinkCustomerToGiftCardRequest.new(params).to_h non_body_param_names = ["gift_card_id"] body = request_data.except(*non_body_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/gift-cards/#{params[:gift_card_id]}/link-customer", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::LinkCustomerToGiftCardResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListGiftCardsResponse
Lists all gift cards. You can specify optional filters to retrieve a subset of the gift cards. Results are sorted by ‘created_at` in ascending order.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/square/gift_cards/client.rb', line 30 def list(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[type state limit cursor customer_id] query_params = {} query_params["type"] = params[:type] if params.key?(:type) query_params["state"] = params[:state] if params.key?(:state) query_params["limit"] = params[:limit] if params.key?(:limit) query_params["cursor"] = params[:cursor] if params.key?(:cursor) query_params["customer_id"] = params[:customer_id] if params.key?(:customer_id) params.except(*query_param_names) Square::Internal::CursorItemIterator.new( cursor_field: :cursor, item_field: :gift_cards, initial_cursor: query_params[:cursor] ) do |next_cursor| query_params[:cursor] = next_cursor request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/gift-cards", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::ListGiftCardsResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#unlink_customer(request_options: {}, **params) ⇒ Square::Types::UnlinkCustomerFromGiftCardResponse
Unlinks a customer from a gift card, which is also referred to as removing a card on file.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/square/gift_cards/client.rb', line 227 def unlink_customer(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request_data = Square::GiftCards::Types::UnlinkCustomerFromGiftCardRequest.new(params).to_h non_body_param_names = ["gift_card_id"] body = request_data.except(*non_body_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/gift-cards/#{params[:gift_card_id]}/unlink-customer", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::UnlinkCustomerFromGiftCardResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |