Class: Square::LoyaltyApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/square/api/loyalty_api.rb

Overview

LoyaltyApi

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#execute_request, #get_user_agent, #validate_parameters, #validate_parameters_types

Constructor Details

#initialize(config, http_call_back: nil) ⇒ LoyaltyApi

Returns a new instance of LoyaltyApi.



4
5
6
# File 'lib/square/api/loyalty_api.rb', line 4

def initialize(config, http_call_back: nil)
  super(config, http_call_back: http_call_back)
end

Instance Method Details

#accumulate_loyalty_points(account_id:, body:) ⇒ AccumulateLoyaltyPointsResponse Hash

Adds points earned from a purchase to a [loyalty account]($m/LoyaltyAccount).

  • If you are using the Orders API to manage orders, provide the

`order_id`. Square reads the order to compute the points earned from both the base loyalty program and an associated [loyalty promotion]($m/LoyaltyPromotion). For purchases that qualify for multiple accrual rules, Square computes points based on the accrual rule that grants the most points. For purchases that qualify for multiple promotions, Square computes points based on the most recently created promotion. A purchase must first qualify for program points to be eligible for promotion points.

  • If you are not using the Orders API to manage orders, provide `points`

with the number of points to add. You must first perform a client-side computation of the points earned from the loyalty program and loyalty promotion. For spend-based and visit-based programs, you can call [CalculateLoyaltyPoints]($e/Loyalty/CalculateLoyaltyPoints) to compute the points earned from the loyalty program (but not points earned from a loyalty promotion). [loyalty account]($m/LoyaltyAccount). containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • account_id (String)

    Required parameter: The ID of the target

  • body (AccumulateLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (AccumulateLoyaltyPointsResponse Hash)

    response from the API call



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/square/api/loyalty_api.rb', line 144

def accumulate_loyalty_points(account_id:,
                              body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}/accumulate'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#adjust_loyalty_points(account_id:, body:) ⇒ AdjustLoyaltyPointsResponse Hash

Adds points to or subtracts points from a buyer's account. Use this endpoint only when you need to manually adjust points. Otherwise, in your application flow, you call [AccumulateLoyaltyPoints]($e/Loyalty/AccumulateLoyaltyPoints) to add points when a buyer pays for the purchase. [loyalty account]($m/LoyaltyAccount). containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • account_id (String)

    Required parameter: The ID of the target

  • body (AdjustLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (AdjustLoyaltyPointsResponse Hash)

    response from the API call



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/square/api/loyalty_api.rb', line 189

def adjust_loyalty_points(account_id:,
                          body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}/adjust'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#calculate_loyalty_points(program_id:, body:) ⇒ CalculateLoyaltyPointsResponse Hash

Calculates the number of points a buyer can earn from a purchase. Applications might call this endpoint to display the points to the buyer.

  • If you are using the Orders API to manage orders, provide the `order_id`

and (optional) `loyalty_account_id`. Square reads the order to compute the points earned from the base loyalty program and an associated [loyalty promotion]($m/LoyaltyPromotion).

  • If you are not using the Orders API to manage orders, provide

`transaction_amount_money` with the purchase amount. Square uses this amount to calculate the points earned from the base loyalty program, but not points earned from a loyalty promotion. For spend-based and visit-based programs, the `tax_mode` setting of the accrual rule indicates how taxes should be treated for loyalty points accrual. If the purchase qualifies for program points, call [ListLoyaltyPromotions]($e/Loyalty/ListLoyaltyPromotions) and perform a client-side computation to calculate whether the purchase also qualifies for promotion points. For more information, see [Calculating promotion points](developer.squareup.com/docs/loyalty-api/loyalty-promotions #calculate-promotion-points). program]($m/LoyaltyProgram), which defines the rules for accruing points. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • program_id (String)

    Required parameter: The ID of the [loyalty

  • body (CalculateLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (CalculateLoyaltyPointsResponse Hash)

    response from the API call



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/square/api/loyalty_api.rb', line 374

def calculate_loyalty_points(program_id:,
                             body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/calculate'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#cancel_loyalty_promotion(promotion_id:, program_id:) ⇒ CancelLoyaltyPromotionResponse Hash

Cancels a loyalty promotion. Use this endpoint to cancel an `ACTIVE` promotion earlier than the end date, cancel an `ACTIVE` promotion when an end date is not specified, or cancel a `SCHEDULED` promotion. Because updating a promotion is not supported, you can also use this endpoint to cancel a promotion before you create a new one. This endpoint sets the loyalty promotion to the `CANCELED` state promotion]($m/LoyaltyPromotion) to cancel. You can cancel a promotion that has an `ACTIVE` or `SCHEDULED` status. program]($m/LoyaltyProgram).

Parameters:

  • promotion_id (String)

    Required parameter: The ID of the [loyalty

  • program_id (String)

    Required parameter: The ID of the base [loyalty

Returns:

  • (CancelLoyaltyPromotionResponse Hash)

    response from the API call



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/square/api/loyalty_api.rb', line 579

def cancel_loyalty_promotion(promotion_id:,
                             program_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/promotions/{promotion_id}/cancel'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'promotion_id' => { 'value' => promotion_id, 'encode' => true },
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_loyalty_account(body:) ⇒ CreateLoyaltyAccountResponse Hash

Creates a loyalty account. To create a loyalty account, you must provide the `program_id` and a `mapping` with the `phone_number` of the buyer. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateLoyaltyAccountRequest)

    Required parameter: An object

Returns:

  • (CreateLoyaltyAccountResponse Hash)

    response from the API call



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/square/api/loyalty_api.rb', line 14

def (body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_loyalty_promotion(program_id:, body:) ⇒ CreateLoyaltyPromotionResponse Hash

Creates a loyalty promotion for a [loyalty program]($m/LoyaltyProgram). A loyalty promotion enables buyers to earn points in addition to those earned from the base loyalty program. This endpoint sets the loyalty promotion to the `ACTIVE` or `SCHEDULED` status, depending on the `available_time` setting. A loyalty program can have a maximum of 10 loyalty promotions with an `ACTIVE` or `SCHEDULED` status. program]($m/LoyaltyProgram) to associate with the promotion. To get the program ID, call [RetrieveLoyaltyProgram]($e/Loyalty/RetrieveLoyaltyProgram) using the `main` keyword. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • program_id (String)

    Required parameter: The ID of the [loyalty

  • body (CreateLoyaltyPromotionRequest)

    Required parameter: An object

Returns:

  • (CreateLoyaltyPromotionResponse Hash)

    response from the API call



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/square/api/loyalty_api.rb', line 490

def create_loyalty_promotion(program_id:,
                             body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/promotions'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_loyalty_reward(body:) ⇒ CreateLoyaltyRewardResponse Hash

Creates a loyalty reward. In the process, the endpoint does following:

  • Uses the `reward_tier_id` in the request to determine the number of

points to lock for this reward.

  • If the request includes `order_id`, it adds the reward and related

discount to the order. After a reward is created, the points are locked and not available for the buyer to redeem another reward. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateLoyaltyRewardRequest)

    Required parameter: An object

Returns:

  • (CreateLoyaltyRewardResponse Hash)

    response from the API call



624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
# File 'lib/square/api/loyalty_api.rb', line 624

def create_loyalty_reward(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#delete_loyalty_reward(reward_id:) ⇒ DeleteLoyaltyRewardResponse Hash

Deletes a loyalty reward by doing the following:

  • Returns the loyalty points back to the loyalty account.

  • If an order ID was specified when the reward was created

(see [CreateLoyaltyReward]($e/Loyalty/CreateLoyaltyReward)), it updates the order by removing the reward and related discounts. You cannot delete a reward that has reached the terminal state (REDEEMED). reward]($m/LoyaltyReward) to delete.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (DeleteLoyaltyRewardResponse Hash)

    response from the API call



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
# File 'lib/square/api/loyalty_api.rb', line 703

def delete_loyalty_reward(reward_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.delete(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#list_loyalty_programsListLoyaltyProgramsResponse Hash

Returns a list of loyalty programs in the seller's account. Loyalty programs define how buyers can earn points and redeem points for rewards. Square sellers can have only one loyalty program, which is created and managed from the Seller Dashboard. For more information, see [Loyalty Program Overview](developer.squareup.com/docs/loyalty/overview). Replaced with [RetrieveLoyaltyProgram]($e/Loyalty/RetrieveLoyaltyProgram) when used with the keyword `main`.

Returns:

  • (ListLoyaltyProgramsResponse Hash)

    response from the API call



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/square/api/loyalty_api.rb', line 273

def list_loyalty_programs
  warn 'Endpoint list_loyalty_programs in LoyaltyApi is deprecated'
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#list_loyalty_promotions(program_id:, status: nil, cursor: nil, limit: nil) ⇒ ListLoyaltyPromotionsResponse Hash

Lists the loyalty promotions associated with a [loyalty program]($m/LoyaltyProgram). Results are sorted by the `created_at` date in descending order (newest to oldest). program]($m/LoyaltyProgram). To get the program ID, call [RetrieveLoyaltyProgram]($e/Loyalty/RetrieveLoyaltyProgram) using the `main` keyword. filter the results by. If a status is provided, only loyalty promotions with the specified status are returned. Otherwise, all loyalty promotions associated with the loyalty program are returned. paged response from the previous call to this endpoint. Provide this cursor to retrieve the next page of results for your original request. For more information, see [Pagination](developer.squareup.com/docs/build-basics/common-api-p atterns/pagination). to return in a single paged response. The minimum value is 1 and the maximum value is 30. The default value is 30. For more information, see [Pagination](developer.squareup.com/docs/build-basics/common-api-p atterns/pagination).

Parameters:

  • program_id (String)

    Required parameter: The ID of the base [loyalty

  • status (LoyaltyPromotionStatus) (defaults to: nil)

    Optional parameter: The status to

  • cursor (String) (defaults to: nil)

    Optional parameter: The cursor returned in the

  • limit (Integer) (defaults to: nil)

    Optional parameter: The maximum number of results

Returns:

  • (ListLoyaltyPromotionsResponse Hash)

    response from the API call



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/square/api/loyalty_api.rb', line 432

def list_loyalty_promotions(program_id:,
                            status: nil,
                            cursor: nil,
                            limit: nil)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/promotions'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_builder = APIHelper.append_url_with_query_parameters(
    _query_builder,
    'status' => status,
    'cursor' => cursor,
    'limit' => limit
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#redeem_loyalty_reward(reward_id:, body:) ⇒ RedeemLoyaltyRewardResponse Hash

Redeems a loyalty reward. The endpoint sets the reward to the `REDEEMED` terminal state. If you are using your own order processing system (not using the Orders API), you call this endpoint after the buyer paid for the purchase. After the reward reaches the terminal state, it cannot be deleted. In other words, points used for the reward cannot be returned to the account. reward]($m/LoyaltyReward) to redeem. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

  • body (RedeemLoyaltyRewardRequest)

    Required parameter: An object

Returns:

  • (RedeemLoyaltyRewardResponse Hash)

    response from the API call



783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/square/api/loyalty_api.rb', line 783

def redeem_loyalty_reward(reward_id:,
                          body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}/redeem'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_account(account_id:) ⇒ RetrieveLoyaltyAccountResponse Hash

Retrieves a loyalty account. account]($m/LoyaltyAccount) to retrieve.

Parameters:

  • account_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (RetrieveLoyaltyAccountResponse Hash)

    response from the API call



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/square/api/loyalty_api.rb', line 85

def (account_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_program(program_id:) ⇒ RetrieveLoyaltyProgramResponse Hash

Retrieves the loyalty program in a seller's account, specified by the program ID or the keyword `main`. Loyalty programs define how buyers can earn points and redeem points for rewards. Square sellers can have only one loyalty program, which is created and managed from the Seller Dashboard. For more information, see [Loyalty Program Overview](developer.squareup.com/docs/loyalty/overview). program or the keyword `main`. Either value can be used to retrieve the single loyalty program that belongs to the seller.

Parameters:

  • program_id (String)

    Required parameter: The ID of the loyalty

Returns:

  • (RetrieveLoyaltyProgramResponse Hash)

    response from the API call



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/square/api/loyalty_api.rb', line 312

def retrieve_loyalty_program(program_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_promotion(promotion_id:, program_id:) ⇒ RetrieveLoyaltyPromotionResponse Hash

Retrieves a loyalty promotion. promotion]($m/LoyaltyPromotion) to retrieve. program]($m/LoyaltyProgram). To get the program ID, call [RetrieveLoyaltyProgram]($e/Loyalty/RetrieveLoyaltyProgram) using the `main` keyword.

Parameters:

  • promotion_id (String)

    Required parameter: The ID of the [loyalty

  • program_id (String)

    Required parameter: The ID of the base [loyalty

Returns:

  • (RetrieveLoyaltyPromotionResponse Hash)

    response from the API call



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/square/api/loyalty_api.rb', line 532

def retrieve_loyalty_promotion(promotion_id:,
                               program_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/promotions/{promotion_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'promotion_id' => { 'value' => promotion_id, 'encode' => true },
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_reward(reward_id:) ⇒ RetrieveLoyaltyRewardResponse Hash

Retrieves a loyalty reward. reward]($m/LoyaltyReward) to retrieve.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (RetrieveLoyaltyRewardResponse Hash)

    response from the API call



738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
# File 'lib/square/api/loyalty_api.rb', line 738

def retrieve_loyalty_reward(reward_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_accounts(body:) ⇒ SearchLoyaltyAccountsResponse Hash

Searches for loyalty accounts in a loyalty program. You can search for a loyalty account using the phone number or customer ID associated with the account. To return all loyalty accounts, specify an empty `query` object or omit it entirely. Search results are sorted by `created_at` in ascending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyAccountsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyAccountsResponse Hash)

    response from the API call



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/square/api/loyalty_api.rb', line 52

def search_loyalty_accounts(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_events(body:) ⇒ SearchLoyaltyEventsResponse Hash

Searches for loyalty events. A Square loyalty program maintains a ledger of events that occur during the lifetime of a buyer's loyalty account. Each change in the point balance (for example, points earned, points redeemed, and points expired) is recorded in the ledger. Using this endpoint, you can search the ledger for events. Search results are sorted by `created_at` in descending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyEventsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyEventsResponse Hash)

    response from the API call



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/square/api/loyalty_api.rb', line 235

def search_loyalty_events(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/events/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_rewards(body:) ⇒ SearchLoyaltyRewardsResponse Hash

Searches for loyalty rewards. This endpoint accepts a request with no query filters and returns results for all loyalty accounts. If you include a `query` object, `loyalty_account_id` is required and `status` is optional. If you know a reward ID, use the [RetrieveLoyaltyReward]($e/Loyalty/RetrieveLoyaltyReward) endpoint. Search results are sorted by `updated_at` in descending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyRewardsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyRewardsResponse Hash)

    response from the API call



664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/square/api/loyalty_api.rb', line 664

def search_loyalty_rewards(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end