Class: Square::LoyaltyApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/square/api/loyalty_api.rb

Overview

LoyaltyApi

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#execute_request, #get_user_agent, #validate_parameters, #validate_parameters_types

Constructor Details

#initialize(config, http_call_back: nil) ⇒ LoyaltyApi

Returns a new instance of LoyaltyApi.



4
5
6
# File 'lib/square/api/loyalty_api.rb', line 4

def initialize(config, http_call_back: nil)
  super(config, http_call_back: http_call_back)
end

Instance Method Details

#accumulate_loyalty_points(account_id:, body:) ⇒ AccumulateLoyaltyPointsResponse Hash

Adds points earned from the base loyalty program to a loyalty account.

  • If you are using the Orders API to manage orders, you only provide the

`order_id`. The endpoint reads the order to compute points to add to the buyer's account.

  • If you are not using the Orders API to manage orders,

you first perform a client-side computation to compute the points. For spend-based and visit-based programs, you can first call [CalculateLoyaltyPoints]($e/Loyalty/CalculateLoyaltyPoints) to compute the points that you provide to this endpoint. This endpoint excludes additional points earned from loyalty promotions. account]($m/LoyaltyAccount) ID to which to add the points. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • account_id (String)

    Required parameter: The [loyalty

  • body (AccumulateLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (AccumulateLoyaltyPointsResponse Hash)

    response from the API call



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/square/api/loyalty_api.rb', line 134

def accumulate_loyalty_points(account_id:,
                              body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}/accumulate'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#adjust_loyalty_points(account_id:, body:) ⇒ AdjustLoyaltyPointsResponse Hash

Adds points to or subtracts points from a buyer's account. Use this endpoint only when you need to manually adjust points. Otherwise, in your application flow, you call [AccumulateLoyaltyPoints]($e/Loyalty/AccumulateLoyaltyPoints) to add points when a buyer pays for the purchase. account]($m/LoyaltyAccount) in which to adjust the points. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • account_id (String)

    Required parameter: The ID of the [loyalty

  • body (AdjustLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (AdjustLoyaltyPointsResponse Hash)

    response from the API call



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/square/api/loyalty_api.rb', line 179

def adjust_loyalty_points(account_id:,
                          body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}/adjust'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#calculate_loyalty_points(program_id:, body:) ⇒ CalculateLoyaltyPointsResponse Hash

Calculates the points a purchase earns from the base loyalty program.

  • If you are using the Orders API to manage orders, you provide the

`order_id` in the request. The endpoint calculates the points by reading the order.

  • If you are not using the Orders API to manage orders, you provide the

purchase amount in the request for the endpoint to calculate the points. An application might call this endpoint to show the points that a buyer can earn with the specific purchase. For spend-based and visit-based programs, the `tax_mode` setting of the accrual rule indicates how taxes should be treated for loyalty points accrual. program]($m/LoyaltyProgram) ID, which defines the rules for accruing points. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • program_id (String)

    Required parameter: The [loyalty

  • body (CalculateLoyaltyPointsRequest)

    Required parameter: An object

Returns:

  • (CalculateLoyaltyPointsResponse Hash)

    response from the API call



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/square/api/loyalty_api.rb', line 353

def calculate_loyalty_points(program_id:,
                             body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}/calculate'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_loyalty_account(body:) ⇒ CreateLoyaltyAccountResponse Hash

Creates a loyalty account. To create a loyalty account, you must provide the `program_id` and a `mapping` with the `phone_number` of the buyer. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateLoyaltyAccountRequest)

    Required parameter: An object

Returns:

  • (CreateLoyaltyAccountResponse Hash)

    response from the API call



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/square/api/loyalty_api.rb', line 14

def (body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_loyalty_reward(body:) ⇒ CreateLoyaltyRewardResponse Hash

Creates a loyalty reward. In the process, the endpoint does following:

  • Uses the `reward_tier_id` in the request to determine the number of

points to lock for this reward.

  • If the request includes `order_id`, it adds the reward and related

discount to the order. After a reward is created, the points are locked and not available for the buyer to redeem another reward. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateLoyaltyRewardRequest)

    Required parameter: An object

Returns:

  • (CreateLoyaltyRewardResponse Hash)

    response from the API call



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/square/api/loyalty_api.rb', line 399

def create_loyalty_reward(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#delete_loyalty_reward(reward_id:) ⇒ DeleteLoyaltyRewardResponse Hash

Deletes a loyalty reward by doing the following:

  • Returns the loyalty points back to the loyalty account.

  • If an order ID was specified when the reward was created

(see [CreateLoyaltyReward]($e/Loyalty/CreateLoyaltyReward)), it updates the order by removing the reward and related discounts. You cannot delete a reward that has reached the terminal state (REDEEMED). reward]($m/LoyaltyReward) to delete.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (DeleteLoyaltyRewardResponse Hash)

    response from the API call



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/square/api/loyalty_api.rb', line 478

def delete_loyalty_reward(reward_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.delete(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#list_loyalty_programsListLoyaltyProgramsResponse Hash

Returns a list of loyalty programs in the seller's account. Loyalty programs define how buyers can earn points and redeem points for rewards. Square sellers can have only one loyalty program, which is created and managed from the Seller Dashboard. For more information, see [Loyalty Program Overview](developer.squareup.com/docs/loyalty/overview). Replaced with [RetrieveLoyaltyProgram]($e/Loyalty/RetrieveLoyaltyProgram) when used with the keyword `main`.

Returns:

  • (ListLoyaltyProgramsResponse Hash)

    response from the API call



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/square/api/loyalty_api.rb', line 263

def list_loyalty_programs
  warn 'Endpoint list_loyalty_programs in LoyaltyApi is deprecated'
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#redeem_loyalty_reward(reward_id:, body:) ⇒ RedeemLoyaltyRewardResponse Hash

Redeems a loyalty reward. The endpoint sets the reward to the `REDEEMED` terminal state. If you are using your own order processing system (not using the Orders API), you call this endpoint after the buyer paid for the purchase. After the reward reaches the terminal state, it cannot be deleted. In other words, points used for the reward cannot be returned to the account. reward]($m/LoyaltyReward) to redeem. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

  • body (RedeemLoyaltyRewardRequest)

    Required parameter: An object

Returns:

  • (RedeemLoyaltyRewardResponse Hash)

    response from the API call



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
# File 'lib/square/api/loyalty_api.rb', line 558

def redeem_loyalty_reward(reward_id:,
                          body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}/redeem'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_account(account_id:) ⇒ RetrieveLoyaltyAccountResponse Hash

Retrieves a loyalty account. account]($m/LoyaltyAccount) to retrieve.

Parameters:

  • account_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (RetrieveLoyaltyAccountResponse Hash)

    response from the API call



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/square/api/loyalty_api.rb', line 85

def (account_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/{account_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'account_id' => { 'value' => , 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_program(program_id:) ⇒ RetrieveLoyaltyProgramResponse Hash

Retrieves the loyalty program in a seller's account, specified by the program ID or the keyword `main`. Loyalty programs define how buyers can earn points and redeem points for rewards. Square sellers can have only one loyalty program, which is created and managed from the Seller Dashboard. For more information, see [Loyalty Program Overview](developer.squareup.com/docs/loyalty/overview). program or the keyword `main`. Either value can be used to retrieve the single loyalty program that belongs to the seller.

Parameters:

  • program_id (String)

    Required parameter: The ID of the loyalty

Returns:

  • (RetrieveLoyaltyProgramResponse Hash)

    response from the API call



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/square/api/loyalty_api.rb', line 302

def retrieve_loyalty_program(program_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/programs/{program_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'program_id' => { 'value' => program_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#retrieve_loyalty_reward(reward_id:) ⇒ RetrieveLoyaltyRewardResponse Hash

Retrieves a loyalty reward. reward]($m/LoyaltyReward) to retrieve.

Parameters:

  • reward_id (String)

    Required parameter: The ID of the [loyalty

Returns:

  • (RetrieveLoyaltyRewardResponse Hash)

    response from the API call



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
# File 'lib/square/api/loyalty_api.rb', line 513

def retrieve_loyalty_reward(reward_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/{reward_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'reward_id' => { 'value' => reward_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_accounts(body:) ⇒ SearchLoyaltyAccountsResponse Hash

Searches for loyalty accounts in a loyalty program. You can search for a loyalty account using the phone number or customer ID associated with the account. To return all loyalty accounts, specify an empty `query` object or omit it entirely. Search results are sorted by `created_at` in ascending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyAccountsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyAccountsResponse Hash)

    response from the API call



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/square/api/loyalty_api.rb', line 52

def search_loyalty_accounts(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/accounts/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_events(body:) ⇒ SearchLoyaltyEventsResponse Hash

Searches for loyalty events. A Square loyalty program maintains a ledger of events that occur during the lifetime of a buyer's loyalty account. Each change in the point balance (for example, points earned, points redeemed, and points expired) is recorded in the ledger. Using this endpoint, you can search the ledger for events. Search results are sorted by `created_at` in descending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyEventsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyEventsResponse Hash)

    response from the API call



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/square/api/loyalty_api.rb', line 225

def search_loyalty_events(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/events/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_loyalty_rewards(body:) ⇒ SearchLoyaltyRewardsResponse Hash

Searches for loyalty rewards. This endpoint accepts a request with no query filters and returns results for all loyalty accounts. If you include a `query` object, `loyalty_account_id` is required and `status` is optional. If you know a reward ID, use the [RetrieveLoyaltyReward]($e/Loyalty/RetrieveLoyaltyReward) endpoint. Search results are sorted by `updated_at` in descending order. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchLoyaltyRewardsRequest)

    Required parameter: An object

Returns:

  • (SearchLoyaltyRewardsResponse Hash)

    response from the API call



439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/square/api/loyalty_api.rb', line 439

def search_loyalty_rewards(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/loyalty/rewards/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end