Class: Square::Merchants::Client
- Inherits:
-
Object
- Object
- Square::Merchants::Client
- Defined in:
- lib/square/merchants/client.rb
Instance Method Summary collapse
- #custom_attribute_definitions ⇒ Square::CustomAttributeDefinitions::Client
- #custom_attributes ⇒ Square::CustomAttributes::Client
-
#get(request_options: {}, **params) ⇒ Square::Types::GetMerchantResponse
Retrieves the ‘Merchant` object for the given `merchant_id`.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListMerchantsResponse
Provides details about the merchant associated with a given access token.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/square/merchants/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#custom_attribute_definitions ⇒ Square::CustomAttributeDefinitions::Client
104 105 106 |
# File 'lib/square/merchants/client.rb', line 104 def custom_attribute_definitions @custom_attribute_definitions ||= Square::Merchants::CustomAttributeDefinitions::Client.new(client: @client) end |
#custom_attributes ⇒ Square::CustomAttributes::Client
109 110 111 |
# File 'lib/square/merchants/client.rb', line 109 def custom_attributes @custom_attributes ||= Square::Merchants::CustomAttributes::Client.new(client: @client) end |
#get(request_options: {}, **params) ⇒ Square::Types::GetMerchantResponse
Retrieves the ‘Merchant` object for the given `merchant_id`.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/square/merchants/client.rb', line 81 def get(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/merchants/#{params[:merchant_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetMerchantResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListMerchantsResponse
Provides details about the merchant associated with a given access token.
The access token used to connect your application to a Square seller is associated with a single merchant. That means that ‘ListMerchants` returns a list with a single `Merchant` object. You can specify your personal access token to get your own merchant information or specify an OAuth token to get the information for the merchant that granted your application access.
If you know the merchant ID, you can also use the [RetrieveMerchant](api-endpoint:Merchants-RetrieveMerchant) endpoint to retrieve the merchant information.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/square/merchants/client.rb', line 34 def list(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[cursor] query_params = {} query_params["cursor"] = params[:cursor] if params.key?(:cursor) params.except(*query_param_names) Square::Internal::CursorItemIterator.new( cursor_field: :cursor, item_field: :merchant, initial_cursor: query_params[:cursor] ) do |next_cursor| query_params[:cursor] = next_cursor request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/merchants", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::ListMerchantsResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |