Class: Square::Orders::Client
- Inherits:
-
Object
- Object
- Square::Orders::Client
- Defined in:
- lib/square/orders/client.rb
Instance Method Summary collapse
-
#batch_get(request_options: {}, **params) ⇒ Square::Types::BatchGetOrdersResponse
Retrieves a set of [orders](entity:Order) by their IDs.
-
#calculate(request_options: {}, **params) ⇒ Square::Types::CalculateOrderResponse
Enables applications to preview order pricing without creating an order.
-
#clone(request_options: {}, **params) ⇒ Square::Types::CloneOrderResponse
Creates a new order, in the ‘DRAFT` state, by duplicating an existing order.
-
#create(request_options: {}, **params) ⇒ Square::Types::CreateOrderResponse
Creates a new [order](entity:Order) that can include information about products for purchase and settings to apply to the purchase.
- #custom_attribute_definitions ⇒ Square::CustomAttributeDefinitions::Client
- #custom_attributes ⇒ Square::CustomAttributes::Client
-
#get(request_options: {}, **params) ⇒ Square::Types::GetOrderResponse
Retrieves an [Order](entity:Order) by ID.
- #initialize(client:) ⇒ Square::Orders::Client constructor
-
#pay(request_options: {}, **params) ⇒ Square::Types::PayOrderResponse
Pay for an [order](entity:Order) using one or more approved [payments](entity:Payment) or settle an order with a total of ‘0`.
-
#search(request_options: {}, **params) ⇒ Square::Types::SearchOrdersResponse
Search all orders for one or more locations.
-
#update(request_options: {}, **params) ⇒ Square::Types::UpdateOrderResponse
Updates an open [order](entity:Order) by adding, replacing, or deleting fields.
Constructor Details
#initialize(client:) ⇒ Square::Orders::Client
7 8 9 |
# File 'lib/square/orders/client.rb', line 7 def initialize(client:) @client = client end |
Instance Method Details
#batch_get(request_options: {}, **params) ⇒ Square::Types::BatchGetOrdersResponse
Retrieves a set of [orders](entity:Order) by their IDs.
If a given order ID does not exist, the ID is ignored instead of generating an error.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/square/orders/client.rb', line 46 def batch_get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders/batch-retrieve", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::BatchGetOrdersResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#calculate(request_options: {}, **params) ⇒ Square::Types::CalculateOrderResponse
Enables applications to preview order pricing without creating an order.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/square/orders/client.rb', line 70 def calculate(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders/calculate", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CalculateOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#clone(request_options: {}, **params) ⇒ Square::Types::CloneOrderResponse
Creates a new order, in the ‘DRAFT` state, by duplicating an existing order. The newly created order has only the core fields (such as line items, taxes, and discounts) copied from the original order.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/square/orders/client.rb', line 95 def clone(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders/clone", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CloneOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#create(request_options: {}, **params) ⇒ Square::Types::CreateOrderResponse
Creates a new [order](entity:Order) that can include information about products for purchase and settings to apply to the purchase.
To pay for a created order, see [Pay for Orders](developer.squareup.com/docs/orders-api/pay-for-orders).
You can modify open orders using the [UpdateOrder](api-endpoint:Orders-UpdateOrder) endpoint.
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/square/orders/client.rb', line 20 def create(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders", body: Square::Types::CreateOrderRequest.new(params).to_h ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::CreateOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#custom_attribute_definitions ⇒ Square::CustomAttributeDefinitions::Client
259 260 261 |
# File 'lib/square/orders/client.rb', line 259 def custom_attribute_definitions @custom_attribute_definitions ||= Square::Orders::CustomAttributeDefinitions::Client.new(client: @client) end |
#custom_attributes ⇒ Square::CustomAttributes::Client
264 265 266 |
# File 'lib/square/orders/client.rb', line 264 def custom_attributes @custom_attributes ||= Square::Orders::CustomAttributes::Client.new(client: @client) end |
#get(request_options: {}, **params) ⇒ Square::Types::GetOrderResponse
Retrieves an [Order](entity:Order) by ID.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/square/orders/client.rb', line 159 def get(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "GET", path: "v2/orders/#{params[:order_id]}" ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::GetOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#pay(request_options: {}, **params) ⇒ Square::Types::PayOrderResponse
Pay for an [order](entity:Order) using one or more approved [payments](entity:Payment) or settle an order with a total of ‘0`.
The total of the ‘payment_ids` listed in the request must be equal to the order total. Orders with a total amount of `0` can be marked as paid by specifying an empty array of `payment_ids` in the request.
To be used with ‘PayOrder`, a payment must:
-
Reference the order by specifying the ‘order_id` when [creating the payment](api-endpoint:Payments-CreatePayment).
Any approved payments that reference the same ‘order_id` not specified in the `payment_ids` is canceled.
-
Be approved with [delayed capture](developer.squareup.com/docs/payments-api/take-payments/card-payments/delayed-capture).
Using a delayed capture payment with ‘PayOrder` completes the approved payment.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/square/orders/client.rb', line 235 def pay(request_options: {}, **params) _path_param_names = ["order_id"] _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders/#{params[:order_id]}/pay", body: params.except(*_path_param_names) ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::PayOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#search(request_options: {}, **params) ⇒ Square::Types::SearchOrdersResponse
Search all orders for one or more locations. Orders include all sales, returns, and exchanges regardless of how or when they entered the Square ecosystem (such as Point of Sale, Invoices, and Connect APIs).
‘SearchOrders` requests need to specify which locations to search and define a [SearchOrdersQuery](entity:SearchOrdersQuery) object that controls how to sort or filter the results. Your `SearchOrdersQuery` can:
Set filter criteria.
Set the sort order.
Determine whether to return results as complete `Order` objects or as
[OrderEntry](entity:OrderEntry) objects.
Note that details for orders processed with Square Point of Sale while in offline mode might not be transmitted to Square for up to 72 hours. Offline orders have a ‘created_at` value that reflects the time the order was created, not the time it was subsequently transmitted to Square.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/square/orders/client.rb', line 135 def search(request_options: {}, **params) _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "POST", path: "v2/orders/search", body: params ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::SearchOrdersResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Square::Types::UpdateOrderResponse
Updates an open [order](entity:Order) by adding, replacing, or deleting fields. Orders with a ‘COMPLETED` or `CANCELED` state cannot be updated.
An ‘UpdateOrder` request requires the following:
-
The ‘order_id` in the endpoint path, identifying the order to update.
-
The latest ‘version` of the order to update.
-
The [sparse order](developer.squareup.com/docs/orders-api/manage-orders/update-orders#sparse-order-objects)
containing only the fields to update and the version to which the update is being applied.
-
If deleting fields, the [dot notation paths](developer.squareup.com/docs/orders-api/manage-orders/update-orders#identifying-fields-to-delete)
identifying the fields to clear.
To pay for an order, see [Pay for Orders](developer.squareup.com/docs/orders-api/pay-for-orders).
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/square/orders/client.rb', line 196 def update(request_options: {}, **params) _path_param_names = ["order_id"] _request = Square::Internal::JSON::Request.new( base_url: [:base_url] || Square::Environment::PRODUCTION, method: "PUT", path: "v2/orders/#{params[:order_id]}", body: params.except(*_path_param_names) ) begin _response = @client.send(_request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = _response.code.to_i if code.between?(200, 299) Square::Types::UpdateOrderResponse.load(_response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(_response.body, code: code) end end |