Class: Square::Payments::Client
- Inherits:
-
Object
- Object
- Square::Payments::Client
- Defined in:
- lib/square/payments/client.rb
Instance Method Summary collapse
-
#cancel(request_options: {}, **params) ⇒ Square::Types::CancelPaymentResponse
Cancels (voids) a payment.
-
#cancel_by_idempotency_key(request_options: {}, **params) ⇒ Square::Types::CancelPaymentByIdempotencyKeyResponse
Cancels (voids) a payment identified by the idempotency key that is specified in the request.
-
#complete(request_options: {}, **params) ⇒ Square::Types::CompletePaymentResponse
Completes (captures) a payment.
-
#create(request_options: {}, **params) ⇒ Square::Types::CreatePaymentResponse
Creates a payment using the provided source.
-
#get(request_options: {}, **params) ⇒ Square::Types::GetPaymentResponse
Retrieves details for a specific payment.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListPaymentsResponse
Retrieves a list of payments taken by the account making the request.
-
#update(request_options: {}, **params) ⇒ Square::Types::UpdatePaymentResponse
Updates a payment with the APPROVED status.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/square/payments/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#cancel(request_options: {}, **params) ⇒ Square::Types::CancelPaymentResponse
Cancels (voids) a payment. You can use this endpoint to cancel a payment with the APPROVED ‘status`.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/square/payments/client.rb', line 265 def cancel(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/payments/#{params[:payment_id]}/cancel", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CancelPaymentResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#cancel_by_idempotency_key(request_options: {}, **params) ⇒ Square::Types::CancelPaymentByIdempotencyKeyResponse
Cancels (voids) a payment identified by the idempotency key that is specified in the request.
Use this method when the status of a ‘CreatePayment` request is unknown (for example, after you send a `CreatePayment` request, a network error occurs and you do not get a response). In this case, you can direct Square to cancel the payment using this endpoint. In the request, you provide the same idempotency key that you provided in your `CreatePayment` request that you want to cancel. After canceling the payment, you can submit your `CreatePayment` request again.
Note that if no payment with the specified idempotency key is found, no action is taken and the endpoint returns successfully.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/square/payments/client.rb', line 155 def cancel_by_idempotency_key(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/payments/cancel", body: Square::Payments::Types::CancelPaymentByIdempotencyKeyRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CancelPaymentByIdempotencyKeyResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#complete(request_options: {}, **params) ⇒ Square::Types::CompletePaymentResponse
Completes (captures) a payment. By default, payments are set to complete immediately after they are created.
You can use this endpoint to complete a payment with the APPROVED ‘status`.
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/square/payments/client.rb', line 302 def complete(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request_data = Square::Payments::Types::CompletePaymentRequest.new(params).to_h non_body_param_names = ["payment_id"] body = request_data.except(*non_body_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/payments/#{params[:payment_id]}/complete", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CompletePaymentResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#create(request_options: {}, **params) ⇒ Square::Types::CreatePaymentResponse
Creates a payment using the provided source. You can use this endpoint to charge a card (credit/debit card or Square gift card) or record a payment that the seller received outside of Square (cash payment from a buyer or a payment that an external entity processed on behalf of the seller).
The endpoint creates a ‘Payment` object and returns it in the response.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/square/payments/client.rb', line 111 def create(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "v2/payments", body: Square::Payments::Types::CreatePaymentRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::CreatePaymentResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Square::Types::GetPaymentResponse
Retrieves details for a specific payment.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/square/payments/client.rb', line 190 def get(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/payments/#{params[:payment_id]}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::GetPaymentResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Square::Types::ListPaymentsResponse
Retrieves a list of payments taken by the account making the request.
Results are eventually consistent, and new payments or changes to payments might take several seconds to appear.
The maximum results per page is 100.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/square/payments/client.rb', line 44 def list(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[begin_time end_time sort_order cursor location_id total last_4 card_brand limit is_offline_payment offline_begin_time offline_end_time updated_at_begin_time updated_at_end_time sort_field] query_params = {} query_params["begin_time"] = params[:begin_time] if params.key?(:begin_time) query_params["end_time"] = params[:end_time] if params.key?(:end_time) query_params["sort_order"] = params[:sort_order] if params.key?(:sort_order) query_params["cursor"] = params[:cursor] if params.key?(:cursor) query_params["location_id"] = params[:location_id] if params.key?(:location_id) query_params["total"] = params[:total] if params.key?(:total) query_params["last_4"] = params[:last_4] if params.key?(:last_4) query_params["card_brand"] = params[:card_brand] if params.key?(:card_brand) query_params["limit"] = params[:limit] if params.key?(:limit) query_params["is_offline_payment"] = params[:is_offline_payment] if params.key?(:is_offline_payment) query_params["offline_begin_time"] = params[:offline_begin_time] if params.key?(:offline_begin_time) query_params["offline_end_time"] = params[:offline_end_time] if params.key?(:offline_end_time) query_params["updated_at_begin_time"] = params[:updated_at_begin_time] if params.key?(:updated_at_begin_time) query_params["updated_at_end_time"] = params[:updated_at_end_time] if params.key?(:updated_at_end_time) query_params["sort_field"] = params[:sort_field] if params.key?(:sort_field) params.except(*query_param_names) Square::Internal::CursorItemIterator.new( cursor_field: :cursor, item_field: :payments, initial_cursor: query_params[:cursor] ) do |next_cursor| query_params[:cursor] = next_cursor request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/payments", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::ListPaymentsResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Square::Types::UpdatePaymentResponse
Updates a payment with the APPROVED status. You can update the ‘amount_money` and `tip_money` using this endpoint.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/square/payments/client.rb', line 225 def update(request_options: {}, **params) params = Square::Internal::Types::Utils.normalize_keys(params) request_data = Square::Payments::Types::UpdatePaymentRequest.new(params).to_h non_body_param_names = ["payment_id"] body = request_data.except(*non_body_param_names) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "v2/payments/#{params[:payment_id]}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::UpdatePaymentResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |