Class: Square::Sites::Client
- Inherits:
-
Object
- Object
- Square::Sites::Client
- Defined in:
- lib/square/sites/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Square::Types::ListSitesResponse
Lists the Square Online sites that belong to a seller.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/square/sites/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}, **params) ⇒ Square::Types::ListSitesResponse
Lists the Square Online sites that belong to a seller. Sites are listed in descending order by the ‘created_at` date.
Note: Square Online APIs are publicly available as part of an early access program. For more information, see [Early access program for Square Online APIs](developer.squareup.com/docs/online-api#early-access-program-for-square-online-apis).
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/square/sites/client.rb', line 30 def list(request_options: {}, **params) Square::Internal::Types::Utils.normalize_keys(params) request = Square::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v2/sites", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Square::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Square::Types::ListSitesResponse.load(response.body) else error_class = Square::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |