Class: Square::TerminalApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/square/api/terminal_api.rb

Overview

TerminalApi

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#execute_request, #get_user_agent, #validate_parameters

Constructor Details

#initialize(config, http_call_back: nil) ⇒ TerminalApi

Returns a new instance of TerminalApi.



4
5
6
# File 'lib/square/api/terminal_api.rb', line 4

def initialize(config, http_call_back: nil)
  super(config, http_call_back: http_call_back)
end

Instance Method Details

#cancel_terminal_checkout(checkout_id:) ⇒ CancelTerminalCheckoutResponse Hash

Cancels a Terminal checkout request if the status of the request permits it. desired `TerminalCheckout`.

Parameters:

  • checkout_id (String)

    Required parameter: The unique ID for the

Returns:

  • (CancelTerminalCheckoutResponse Hash)

    response from the API call



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/square/api/terminal_api.rb', line 122

def cancel_terminal_checkout(checkout_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/checkouts/{checkout_id}/cancel'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'checkout_id' => { 'value' => checkout_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#cancel_terminal_refund(terminal_refund_id:) ⇒ CancelTerminalRefundResponse Hash

Cancels an Interac Terminal refund request by refund request ID if the status of the request permits it. the desired `TerminalRefund`.

Parameters:

  • terminal_refund_id (String)

    Required parameter: The unique ID for

Returns:

  • (CancelTerminalRefundResponse Hash)

    response from the API call



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/square/api/terminal_api.rb', line 268

def cancel_terminal_refund(terminal_refund_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/refunds/{terminal_refund_id}/cancel'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'terminal_refund_id' => { 'value' => terminal_refund_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_terminal_checkout(body:) ⇒ CreateTerminalCheckoutResponse Hash

Creates a Terminal checkout request and sends it to the specified device to take a payment for the requested amount. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateTerminalCheckoutRequest)

    Required parameter: An object

Returns:

  • (CreateTerminalCheckoutResponse Hash)

    response from the API call



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/square/api/terminal_api.rb', line 15

def create_terminal_checkout(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/checkouts'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#create_terminal_refund(body:) ⇒ CreateTerminalRefundResponse Hash

Creates a request to refund an Interac payment completed on a Square Terminal. Refunds for Interac payments on a Square Terminal are supported only for Interac debit cards in Canada. Other refunds for Terminal payments should use the Refunds API. For more information, see [Refunds API]($e/Refunds). containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (CreateTerminalRefundRequest)

    Required parameter: An object

Returns:

  • (CreateTerminalRefundResponse Hash)

    response from the API call



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/square/api/terminal_api.rb', line 162

def create_terminal_refund(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/refunds'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#get_terminal_checkout(checkout_id:) ⇒ GetTerminalCheckoutResponse Hash

Retrieves a Terminal checkout request by `checkout_id`. Terminal checkout requests are available for 30 days. desired `TerminalCheckout`.

Parameters:

  • checkout_id (String)

    Required parameter: The unique ID for the

Returns:

  • (GetTerminalCheckoutResponse Hash)

    response from the API call



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/square/api/terminal_api.rb', line 86

def get_terminal_checkout(checkout_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/checkouts/{checkout_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'checkout_id' => { 'value' => checkout_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#get_terminal_refund(terminal_refund_id:) ⇒ GetTerminalRefundResponse Hash

Retrieves an Interac Terminal refund object by ID. Terminal refund objects are available for 30 days. the desired `TerminalRefund`.

Parameters:

  • terminal_refund_id (String)

    Required parameter: The unique ID for

Returns:

  • (GetTerminalRefundResponse Hash)

    response from the API call



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/square/api/terminal_api.rb', line 232

def get_terminal_refund(terminal_refund_id:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/refunds/{terminal_refund_id}'
  _query_builder = APIHelper.append_url_with_template_parameters(
    _query_builder,
    'terminal_refund_id' => { 'value' => terminal_refund_id, 'encode' => true }
  )
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.get(
    _query_url,
    headers: _headers
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_terminal_checkouts(body:) ⇒ SearchTerminalCheckoutsResponse Hash

Returns a filtered list of Terminal checkout requests created by the application making the request. Only Terminal checkout requests created for the merchant scoped to the OAuth token are returned. Terminal checkout requests are available for 30 days. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchTerminalCheckoutsRequest)

    Required parameter: An object

Returns:

  • (SearchTerminalCheckoutsResponse Hash)

    response from the API call



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/square/api/terminal_api.rb', line 52

def search_terminal_checkouts(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/checkouts/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end

#search_terminal_refunds(body:) ⇒ SearchTerminalRefundsResponse Hash

Retrieves a filtered list of Interac Terminal refund requests created by the seller making the request. Terminal refund requests are available for 30 days. containing the fields to POST for the request. See the corresponding object definition for field details.

Parameters:

  • body (SearchTerminalRefundsRequest)

    Required parameter: An object

Returns:

  • (SearchTerminalRefundsResponse Hash)

    response from the API call



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/square/api/terminal_api.rb', line 198

def search_terminal_refunds(body:)
  # Prepare query url.
  _query_builder = config.get_base_uri
  _query_builder << '/v2/terminals/refunds/search'
  _query_url = APIHelper.clean_url _query_builder

  # Prepare headers.
  _headers = {
    'accept' => 'application/json',
    'Content-Type' => 'application/json'
  }

  # Prepare and execute HttpRequest.
  _request = config.http_client.post(
    _query_url,
    headers: _headers,
    parameters: body.to_json
  )
  OAuth2.apply(config, _request)
  _response = execute_request(_request)

  # Return appropriate response type.
  decoded = APIHelper.json_deserialize(_response.raw_body)
  _errors = APIHelper.map_response(decoded, ['errors'])
  ApiResponse.new(
    _response, data: decoded, errors: _errors
  )
end