Class: Square::Types::CardSurchargeDetails
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CardSurchargeDetails
- Defined in:
- lib/square/types/card_surcharge_details.rb
Overview
Details related to an attempt to apply a card surcharge to this payment. When surcharge eligibility is not known in advance, such as when the card type (debit or credit) is required to make the eligibility determination, proposed_card_surcharge_money and proposed_additional_amount_money will match the values in the request, while card_surcharge_money and additional_amount_money are present only when the payment has a surcharge applied.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model