Class: Square::Types::CashDrawerShiftSummary
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CashDrawerShiftSummary
- Defined in:
- lib/square/types/cash_drawer_shift_summary.rb
Overview
The summary of a closed cash drawer shift. This model contains only the money counted to start a cash drawer shift, counted at the end of the shift, and the amount that should be in the drawer at shift end based on summing all cash drawer shift events.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model