Class: Square::Types::CatalogCustomAttributeDefinition
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CatalogCustomAttributeDefinition
- Defined in:
- lib/square/types/catalog_custom_attribute_definition.rb
Overview
Contains information defining a custom attribute. Custom attributes are intended to store additional information about a catalog object or to associate a catalog object with an entity in another system. Do not use custom attributes to store any sensitive information (personally identifiable information, card details, etc.). Read more about custom attributes
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model