Class: Square::Types::CatalogQueryText
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CatalogQueryText
- Defined in:
- lib/square/types/catalog_query_text.rb
Overview
The query filter to return the search result whose searchable attribute values contain all of the specified keywords or tokens, independent of the token order or case.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model