Class: Square::Types::CustomerCustomAttributeVisibleUpdatedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomerCustomAttributeVisibleUpdatedEvent
- Defined in:
- lib/square/types/customer_custom_attribute_visible_updated_event.rb
Overview
Published when a customer [custom attribute](entity:CustomAttribute) that is visible to the subscribing application is created or updated. A notification is sent when:
-
Your application creates or updates a custom attribute owned by your application, regardless of the ‘visibility`
setting.
-
Any application creates or updates a custom attribute whose ‘visibility` is `VISIBILITY_READ_ONLY`
or ‘VISIBILITY_READ_WRITE_VALUES`.
Custom attributes set to ‘VISIBILITY_READ_WRITE_VALUES` can be created or updated by any application, but those set to `VISIBILITY_READ_ONLY` or `VISIBILITY_HIDDEN` can only be created or updated by the owner. Custom attributes are owned by the application that created the corresponding [custom attribute definition](entity:CustomAttributeDefinition).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model