Class: Square::Types::CustomerDeletedEventEventContextMerge
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::CustomerDeletedEventEventContextMerge
- Defined in:
- lib/square/types/customer_deleted_event_event_context_merge.rb
Overview
Information about a merge operation, which creates a new customer using aggregated properties from two or more existing customers.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model