Class: Square::Types::GiftCardActivityUpdatedEvent
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::GiftCardActivityUpdatedEvent
- Defined in:
- lib/square/types/gift_card_activity_updated_event.rb
Overview
Published when a [gift card activity](entity:GiftCardActivity) is updated. Subscribe to this event to be notified about the following changes:
-
An update to the ‘REDEEM` activity for a gift card redemption made from a Square product (such as Square Point
of Sale). These redemptions are initially assigned a ‘PENDING` state, but then change to a `COMPLETED` or `CANCELED` state.
-
An update to the ‘IMPORT` activity for an imported gift card when the balance is later adjusted by Square.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model