Class: Square::Types::InventoryPhysicalCount
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::InventoryPhysicalCount
- Defined in:
- lib/square/types/inventory_physical_count.rb
Overview
Represents the quantity of an item variation that is physically present at a specific location, verified by a seller or a seller’s employee. For example, a physical count might come from an employee counting the item variations on hand or from syncing with an external system.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model