Class: Square::Types::InvoiceRecipient
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::InvoiceRecipient
- Defined in:
- lib/square/types/invoice_recipient.rb
Overview
Represents a snapshot of customer data. This object stores customer data that is displayed on the invoice and that Square uses to deliver the invoice.
When you provide a customer ID for a draft invoice, Square retrieves the associated customer profile and populates the remaining ‘InvoiceRecipient` fields. You cannot update these fields after the invoice is published. Square updates the customer ID in response to a merge operation, but does not update other fields.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model