Class: Square::Types::LoyaltyProgramRewardTier
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::LoyaltyProgramRewardTier
- Defined in:
- lib/square/types/loyalty_program_reward_tier.rb
Overview
Represents a reward tier in a loyalty program. A reward tier defines how buyers can redeem points for a reward, such as the number of points required and the value and scope of the discount. A loyalty program can offer multiple reward tiers.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model