Class: Square::Types::LoyaltyPromotionTriggerLimit
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::LoyaltyPromotionTriggerLimit
- Defined in:
- lib/square/types/loyalty_promotion_trigger_limit.rb
Overview
Represents the number of times a buyer can earn points during a [loyalty promotion](entity:LoyaltyPromotion). If this field is not set, buyers can trigger the promotion an unlimited number of times to earn points during the time that the promotion is available.
A purchase that is disqualified from earning points because of this limit might qualify for another active promotion.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model