Class: Square::Types::Money
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Money
- Defined in:
- lib/square/types/money.rb
Overview
Represents an amount of money. ‘Money` fields can be signed or unsigned. Fields that do not explicitly define whether they are signed or unsigned are considered unsigned and can only hold positive amounts. For signed fields, the sign of the value indicates the purpose of the money transfer. See [Working with Monetary Amounts](developer.squareup.com/docs/build-basics/working-with-monetary-amounts) for more information.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model