Class: Square::Types::Order
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Order
- Defined in:
- lib/square/types/order.rb
Overview
Contains all information related to a single order to process with Square, including line items that specify the products to purchase. ‘Order` objects also include information about any associated tenders, refunds, and returns.
All Connect V2 Transactions have all been converted to Orders including all associated itemization data.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model