Class: Square::Types::OrderLineItemAppliedDiscount
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::OrderLineItemAppliedDiscount
- Defined in:
- lib/square/types/order_line_item_applied_discount.rb
Overview
Represents an applied portion of a discount to a line item in an order.
Order scoped discounts have automatically applied discounts present for each line item. Line-item scoped discounts must have applied discounts added manually for any applicable line items. The corresponding applied money is automatically computed based on participating line items.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model