Class: Square::Types::OrderLineItemAppliedTax
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::OrderLineItemAppliedTax
- Defined in:
- lib/square/types/order_line_item_applied_tax.rb
Overview
Represents an applied portion of a tax to a line item in an order.
Order-scoped taxes automatically include the applied taxes in each line item. Line item taxes must be referenced from any applicable line items. The corresponding applied money is automatically computed, based on the set of participating line items.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model