Class: Square::Types::OrderPricingOptions
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::OrderPricingOptions
- Defined in:
- lib/square/types/order_pricing_options.rb
Overview
Pricing options for an order. The options affect how the order’s price is calculated. They can be used, for example, to apply automatic price adjustments that are based on preconfigured [pricing rules](entity:CatalogPricingRule).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model