Class: Square::Types::OrderRoundingAdjustment
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::OrderRoundingAdjustment
- Defined in:
- lib/square/types/order_rounding_adjustment.rb
Overview
A rounding adjustment of the money being returned. Commonly used to apply cash rounding when the minimum unit of the account is smaller than the lowest physical denomination of the currency.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model