Class: Square::Types::Payout
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Payout
- Defined in:
- lib/square/types/payout.rb
Overview
An accounting of the amount owed the seller and record of the actual transfer to their external bank account or to the Square balance.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model