Class: Square::Types::RiskEvaluation
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::RiskEvaluation
- Defined in:
- lib/square/types/risk_evaluation.rb
Overview
Represents fraud risk information for the associated payment.
When you take a payment through Square’s Payments API (using the ‘CreatePayment` endpoint), Square evaluates it and assigns a risk level to the payment. Sellers can use this information to determine the course of action (for example, provide the goods/services or refund the payment).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model