Class: Square::Types::ScheduledShift
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::ScheduledShift
- Defined in:
- lib/square/types/scheduled_shift.rb
Overview
Represents a specific time slot in a work schedule. This object is used to manage the lifecycle of a scheduled shift from the draft to published state. A scheduled shift contains the latest draft shift details and current published shift details.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model