Class: Square::Types::Shift
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Shift
- Defined in:
- lib/square/types/shift.rb
Overview
A record of the hourly rate, start, and end times for a single work shift for an employee. This might include a record of the start and end times for breaks taken during the shift.
Deprecated at Square API version 2025-05-21. Replaced by [Timecard](entity:Timecard). See the [migration notes](developer.squareup.com/docs/labor-api/what-it-does#migration-notes).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model