Class: Square::Types::Transaction
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::Transaction
- Defined in:
- lib/square/types/transaction.rb
Overview
Represents a transaction processed with Square, either with the Connect API or with Square Point of Sale.
The ‘tenders` field of this object lists all methods of payment used to pay in the transaction.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model