Class: Square::Types::TransferOrderGoodsReceipt

Inherits:
Internal::Types::Model show all
Defined in:
lib/square/types/transfer_order_goods_receipt.rb

Overview

The goods receipt details for a transfer order. This object represents a single receipt of goods against a transfer order, tracking:

  • Which [CatalogItemVariation](entity:CatalogItemVariation)s were received

  • Quantities received in good condition

  • Quantities damaged during transit/handling

  • Quantities canceled during receipt

Multiple goods receipts can be created for a single transfer order to handle:

  • Partial deliveries

  • Multiple shipments

  • Split receipts across different dates

  • Cancellations of specific quantities

Each receipt automatically:

  • Updates the transfer order status

  • Adjusts received quantities

  • Updates inventory levels at both source and destination [Location](entity:Location)s

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Square::Internal::Types::Model