Class: Square::Types::V1Tender
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Square::Types::V1Tender
- Defined in:
- lib/square/types/v_1_tender.rb
Overview
A tender represents a discrete monetary exchange. Square represents this exchange as a money object with a specific currency and amount, where the amount is given in the smallest denomination of the given currency.
Square POS can accept more than one form of tender for a single payment (such as by splitting a bill between a credit card and a gift card). The ‘tender` field of the Payment object lists all forms of tender used for the payment.
Split tender payments behave slightly differently from single tender payments:
The receipt_url for a split tender corresponds only to the first tender listed in the tender field. To get the receipt URLs for the remaining tenders, use the receipt_url fields of the corresponding Tender objects.
*A note on gift cards**: when a customer purchases a Square gift card from a merchant, the merchant receives the full amount of the gift card in the associated payment.
When that gift card is used as a tender, the balance of the gift card is reduced and the merchant receives no funds. A ‘Tender` object with a type of `SQUARE_GIFT_CARD` indicates a gift card was used for some or all of the associated payment.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Square::Internal::Types::Model